@@ -12,7 +12,7 @@ use log::info;
 use num_traits::{FromPrimitive, PrimInt, Signed, ToPrimitive};
 use odbc_api::{
     buffers::{
-        buffer_from_description, AnyColumnViewMut, BinColumnWriter, BufferDescription, BufferKind,
+        AnyColumnViewMut, BinColumnWriter, BufferDescription, BufferKind, ColumnarAnyBuffer,
         NullableSliceMut, TextColumnWriter,
     },
     sys::{Date, Timestamp},
@@ -74,7 +74,7 @@ pub fn insert(odbc_env: &Environment, insert_opt: &InsertOpt) -> Result<(), Erro
 
     // Start with a small initial batch size and reallocate as we encounter larger row groups.
     let mut batch_size = 1;
-    let mut odbc_buffer = buffer_from_description(
+    let mut odbc_buffer = ColumnarAnyBuffer::from_description(
         batch_size,
         column_buf_desc.iter().map(|(desc, _copy_col)| *desc),
     );
@@ -96,7 +96,7 @@ pub fn insert(odbc_env: &Environment, insert_opt: &InsertOpt) -> Result<(), Erro
         if num_rows > batch_size as usize {
             batch_size = num_rows;
             let descs = column_buf_desc.iter().map(|(desc, _)| *desc);
-            odbc_buffer = buffer_from_description(batch_size, descs);
+            odbc_buffer = ColumnarAnyBuffer::from_description(batch_size, descs);
         }
         odbc_buffer.set_num_rows(num_rows);
         pb.set_num_rows_fetched(num_rows);
